EXPORTS
	??1CMultiPartPushMsgEntry@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CMultiPartPushMsgEntry::~CMultiPartPushMsgEntry(void)
	??1CMultipartTextIterator@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CMultipartTextIterator::~CMultipartTextIterator(void)
	??1CUnknownPushMsgEntry@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CUnknownPushMsgEntry::~CUnknownPushMsgEntry(void)
	?FirstL@CMultipartBinIterator@@UAEXXZ @ 4 NONAME ; public: virtual void __thiscall CMultipartBinIterator::FirstL(void)
	?FirstL@CMultipartTextIterator@@UAEXXZ @ 5 NONAME ; public: virtual void __thiscall CMultipartTextIterator::FirstL(void)
	?MessageData@CUnknownPushMsgEntry@@QBEABVTDesC8@@XZ @ 6 NONAME ; public: class TDesC8 const & __thiscall CUnknownPushMsgEntry::MessageData(void)const 
	?NewL@CMultiPartPushMsgEntry@@SAPAV1@XZ @ 7 NONAME ; public: static class CMultiPartPushMsgEntry * __cdecl CMultiPartPushMsgEntry::NewL(void)
	?NewL@CMultipartBinIterator@@SAPAV1@AAVCPushMessage@@@Z @ 8 NONAME ; public: static class CMultipartBinIterator * __cdecl CMultipartBinIterator::NewL(class CPushMessage &)
	?NewL@CMultipartTextIterator@@SAPAV1@AAVCPushMessage@@@Z @ 9 NONAME ; public: static class CMultipartTextIterator * __cdecl CMultipartTextIterator::NewL(class CPushMessage &)
	?NewL@CUnknownPushMsgEntry@@SAPAV1@XZ @ 10 NONAME ; public: static class CUnknownPushMsgEntry * __cdecl CUnknownPushMsgEntry::NewL(void)
	?NextL@CMultipartBinIterator@@UAEHXZ @ 11 NONAME ; public: virtual int __thiscall CMultipartBinIterator::NextL(void)
	?NextL@CMultipartTextIterator@@UAEHXZ @ 12 NONAME ; public: virtual int __thiscall CMultipartTextIterator::NextL(void)
	?PartL@CMultipartBinIterator@@UAEPAVCPushMessage@@XZ @ 13 NONAME ; public: virtual class CPushMessage * __thiscall CMultipartBinIterator::PartL(void)
	?PartL@CMultipartTextIterator@@UAEPAVCPushMessage@@XZ @ 14 NONAME ; public: virtual class CPushMessage * __thiscall CMultipartTextIterator::PartL(void)
	?RetrieveL@CUnknownPushMsgEntry@@UAEXAAVCMsvSession@@J@Z @ 15 NONAME ; public: virtual void __thiscall CUnknownPushMsgEntry::RetrieveL(class CMsvSession &,long)
	?SaveL@CUnknownPushMsgEntry@@UAEJAAVCMsvSession@@J@Z @ 16 NONAME ; public: virtual long __thiscall CUnknownPushMsgEntry::SaveL(class CMsvSession &,long)
	?SetContentTypeL@CMultiPartPushMsgEntry@@QAEXABVTDesC16@@@Z @ 17 NONAME ; public: void __thiscall CMultiPartPushMsgEntry::SetContentTypeL(class TDesC16 const &)
	?SetContentTypeL@CUnknownPushMsgEntry@@QAEXABVTDesC16@@@Z @ 18 NONAME ; public: void __thiscall CUnknownPushMsgEntry::SetContentTypeL(class TDesC16 const &)
	?SetMessageDataL@CUnknownPushMsgEntry@@QAEXABVTDesC8@@@Z @ 19 NONAME ; public: void __thiscall CUnknownPushMsgEntry::SetMessageDataL(class TDesC8 const &)
	?UpdateL@CUnknownPushMsgEntry@@UAEXAAVCMsvSession@@@Z @ 20 NONAME ; public: virtual void __thiscall CUnknownPushMsgEntry::UpdateL(class CMsvSession &)
	?ExternalizeL@CUnknownPushMsgEntry@@EAEXAAVRMsvWriteStream@@@Z @ 21 NONAME ; private: virtual void __thiscall CUnknownPushMsgEntry::ExternalizeL(class RMsvWriteStream &)
	?InternalizeL@CUnknownPushMsgEntry@@EAEXAAVRMsvReadStream@@@Z @ 22 NONAME ; private: virtual void __thiscall CUnknownPushMsgEntry::InternalizeL(class RMsvReadStream &)
	?NewL@CUnknownPushMsgEntry@@SAPAV1@AAH@Z @ 23 NONAME ; public: static class CUnknownPushMsgEntry * __cdecl CUnknownPushMsgEntry::NewL(int &)
	?NewL@CUnknownPushMsgEntry@@SAPAV1@ABVTPtrC8@@@Z @ 24 NONAME ; public: static class CUnknownPushMsgEntry * __cdecl CUnknownPushMsgEntry::NewL(class TPtrC8 const &)
	?NewL@CMultiPartPushMsgEntry@@SAPAV1@AAH@Z @ 25 NONAME ; public: static class CMultiPartPushMsgEntry * __cdecl CMultiPartPushMsgEntry::NewL(int &)
	?NewL@CMultiPartPushMsgEntry@@SAPAV1@ABVTPtrC8@@@Z @ 26 NONAME ; public: static class CMultiPartPushMsgEntry * __cdecl CMultiPartPushMsgEntry::NewL(class TPtrC8 const &)
	?ContentFileNameL@CUnknownPushMsgEntry@@QAEABVTDesC16@@XZ @ 27 NONAME ; public: class TDesC16 const & __thiscall CUnknownPushMsgEntry::ContentFileNameL(void)
	?SetContentFileNameL@CUnknownPushMsgEntry@@QAEXABVTDesC16@@@Z @ 28 NONAME ; void CUnknownPushMsgEntry::SetContentFileNameL(class TDesC16 const &)

